# `narwhals.Expr`

::: narwhals.Expr
    handler: python
    options:
      members:
        - alias
        - all
        - any
        - cast
        - drop_nulls
        - filter
        - is_between
        - is_in
        - is_null
        - max
        - mean
        - min
        - n_unique
        - over
        - unique
        - sample
        - sort
        - std
        - sum
      show_source: false
      show_bases: false
